@@ -64,9 +64,13 @@ class Cache:
         return self._get_container(key, **params)
     
     def get_value(self, key, **params):
+        if isinstance(key, unicode):
+            key = str(key.decode('utf8', 'ignore'))
         return self._get_container(key, **params).get_value()
     
     def set_value(self, key, value, **params):
+        if isinstance(key, unicode):
+            key = str(key.decode('utf8', 'ignore'))
         self._get_container(key, **params).set_value(value)
     
     def remove_value(self, key):
