@@ -1,24 +1,15 @@
-import sys
 from converters import asbool
 from datetime import datetime, timedelta
+import sys
 
 try:
     from paste.registry import StackedObjectProxy
     beaker_session = StackedObjectProxy(name="Beaker Session")
 except:
     pass
-from myghtyutils.session import Session
 from myghtyutils.util import PrefixArgs
 
-
-class request(object):
-    def __init__(self):
-        class headers_out(object):
-            def __init__(self):
-                self.headers = {}
-            def add(self, name, value):
-                self.headers[name] = value
-        self.headers_out = headers_out()
+from api import Session
 
 class SessionObject(object):
     """Session proxy/lazy creator
@@ -37,12 +28,11 @@ class SessionObject(object):
     
     def _session(self):
         """Lazy initial creation of session object"""
-        if not self.__dict__['_sess']:
+        if self.__dict__['_sess'] is None:
             params = self.__dict__['_params']
             environ = self.__dict__['_environ']
-            req = request()
-            self.__dict__['_headers'] = req.headers_out
-            req.headers_in = dict(cookie=environ.get('HTTP_COOKIE'))
+            self.__dict__['_headers'] = req = {'cookie_out':None}
+            req['cookie'] = environ.get('HTTP_COOKIE')
             self.__dict__['_sess'] = Session(req, use_cookies=True, **params)
         return self.__dict__['_sess']
     
@@ -96,8 +86,8 @@ class SessionMiddleware(object):
         environ['beaker.session'] = session
         
         def session_start_response(status, headers, exc_info = None):
-            if session.__dict__['_sess']:
-                cookie = session.__dict__['_headers'].headers.get('set-cookie')
+            if session.__dict__['_sess'] is not None:
+                cookie = session.__dict__['_headers']['cookie_out']
                 if cookie:
                     headers.append(('Set-cookie', cookie))
             return start_response(status, headers, exc_info)
@@ -107,8 +97,9 @@ class SessionMiddleware(object):
             ty, val = sys.exc_info()[:2]
             if isinstance(ty, str):
                 raise ty, val, sys.exc_info()[2]
-            if ty.__name__ == 'HTTPFound' and session.__dict__['_sess']:
-                cookie = session.__dict__['_headers'].headers.get('set-cookie')
+            if ty.__name__ == 'HTTPFound' and \
+                    session.__dict__['_sess'] is not None:
+                cookie = session.__dict__['_headers']['cookie_out']
                 if cookie:
                     val.headers.append(('Set-cookie', cookie))
             raise ty, val, sys.exc_info()[2]
